==> apache-inlong-1.10.0-src.tar.gz: apache-inlong-1.10.0/inlong-dashboard/src/plugins/clusters/defaults/Pulsar.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import i18n from '@/i18n';
import { DataWithBackend } from '@/plugins/DataWithBackend';
import { RenderRow } from '@/plugins/RenderRow';
import { RenderList } from '@/plugins/RenderList';
import { ClusterInfo } from '../common/ClusterInfo';

const { I18n } = DataWithBackend;
const { FieldDecorator } = RenderRow;

export default class PulsarCluster
  extends ClusterInfo
  implements DataWithBackend, RenderRow, RenderList
{
  @FieldDecorator({
    type: 'input',
    tooltip: i18n.t('pages.Clusters.Pulsar.ServiceUrlHelper'),
    rules: [{ required: true }],
    props: {
      placeholder: 'pulsar://127.0.0.1:6650,127.0.1.2:6650',
    },
  })
  @I18n('Service URL')
  url: string;

  @FieldDecorator({
    type: 'input',
    tooltip: i18n.t('pages.Clusters.Pulsar.AdminUrlHelper'),
    rules: [{ required: true }],
    props: {
      placeholder: 'http://127.0.0.1:8080,127.0.1.2:8080',
    },
  })
  @I18n('Admin URL')
  adminUrl: string;

  @FieldDecorator({
    type: 'input',
    rules: [{ required: true }],
    initialValue: 'public',
  })
  @I18n('pages.Clusters.Pulsar.Tenant')
  tenant: string;

  @FieldDecorator({
    type: 'input',
    props: {
      placeholder: i18n.t('pages.Clusters.Pulsar.TokenPlaceholder'),
    },
  })
  @I18n('Token')
  token: string;
}

==> apache-inlong-2.2.0-src.tar.gz: apache-inlong-2.2.0/inlong-dashboard/src/plugins/clusters/defaults/Pulsar.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import i18n from '@/i18n';
import { DataWithBackend } from '@/plugins/DataWithBackend';
import { RenderRow } from '@/plugins/RenderRow';
import { RenderList } from '@/plugins/RenderList';
import { ClusterInfo } from '../common/ClusterInfo';

const { I18n } = DataWithBackend;
const { FieldDecorator } = RenderRow;

export default class PulsarCluster
  extends ClusterInfo
  implements DataWithBackend, RenderRow, RenderList
{
  @FieldDecorator({
    type: 'input',
    tooltip: i18n.t('pages.Clusters.Pulsar.ServiceUrlHelper'),
    rules: [{ required: true }],
    props: {
      placeholder: 'pulsar://127.0.0.1:6650,127.0.1.2:6650',
    },
  })
  @I18n('Service URL')
  url: string;

  @FieldDecorator({
    type: 'input',
    tooltip: i18n.t('pages.Clusters.Pulsar.AdminUrlHelper'),
    rules: [{ required: true }],
    props: {
      placeholder: 'http://127.0.0.1:8080,127.0.1.2:8080',
    },
  })
  @I18n('Admin URL')
  adminUrl: string;

  @FieldDecorator({
    type: 'input',
    rules: [{ required: true }],
    initialValue: 'public',
  })
  @I18n('pages.Clusters.Pulsar.PulsarTenant')
  pulsarTenant: string;

  @FieldDecorator({
    type: 'input',
    props: {
      placeholder: i18n.t('pages.Clusters.Pulsar.TokenPlaceholder'),
    },
  })
  @I18n('Token')
  token: string;
}
